@@ -501,7 +501,7 @@ class Kubedev:
           envs['cmdline']
       ]
       listResourcesCmd = [
-        '/bin/sh', '-c', f'helm get manifest --kubeconfig {kubeconfig} {release_name} | kubectl get -f -'
+        '/bin/sh', '-c', f'helm get manifest --kubeconfig {kubeconfig} {release_name} | kubectl get --kubeconfig {kubeconfig} -f -'
       ]
     if not get_output:
       result = shell_executor.execute(command, {**variables, **envs['envs']})
